@@ -1,11 +1,11 @@
-#$Id: Path.pm 39 2012-11-21 04:26:01Z maj $
+#$Id: Path.pm 41 2012-11-22 01:14:10Z maj $
 package REST::Neo4p::Path;
 use REST::Neo4p::Exceptions;
 use Carp qw(croak carp);
 use strict;
 use warnings;
 BEGIN {
-  $REST::Neo4p::Path::VERSION = '0.20';
+  $REST::Neo4p::Path::VERSION = '0.2001';
 }
 
 sub new {
@@ -78,11 +78,11 @@ REST::Neo4p::Path - Container for Neo4j path elements
 
 =head1 DESCRIPTION
 
-C<REST::Neo4p::Path> provides a container for Neo4j paths as returned
+REST::Neo4p::Path provides a simple container for Neo4j paths as returned
 by Cypher queries. Nodes and relationships are stored in path order.
 
-Currently, creating de novo instances of class is really the job of 
-L<REST::Neo4p::Query|REST::Neo4p::Query>.
+Currently, creating de novo instances of this class is really the job
+of L<REST::Neo4p::Query>.
 
 =head1 METHODS
 
@@ -92,10 +92,14 @@ L<REST::Neo4p::Query|REST::Neo4p::Query>.
 
  @nodes = $path->nodes;
 
+Get the nodes in path order.
+
 =item relationships()
 
  @relationships = $path->relationships;
 
+Get the relationships in path order.
+
 =back
 
 =head1 SEE ALSO
